"""Top-level package for guiprint."""

__author__ = """Md Ashraful Islam"""
__email__ = 'imdashraful17@gmail.com'
__version__ = '0.1.0'

from guiprint.guiprint_core import demoworld
